==> dry-2.3-sources.jar: hudson/plugins/dry/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.dry;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     *  1 new warning
     * 
     */
    public static String DRY_ResultAction_OneNewWarning() {
        return holder.format("DRY.ResultAction.OneNewWarning");
    }

    /**
     *  1 new warning
     * 
     */
    public static Localizable _DRY_ResultAction_OneNewWarning() {
        return new Localizable(holder, "DRY.ResultAction.OneNewWarning");
    }

    /**
     * Duplicate Code
     * 
     */
    public static String DRY_ProjectAction_Name() {
        return holder.format("DRY.ProjectAction.Name");
    }

    /**
     * Duplicate Code
     * 
     */
    public static Localizable _DRY_ProjectAction_Name() {
        return new Localizable(holder, "DRY.ProjectAction.Name");
    }

    /**
     * {0} new warnings
     * 
     */
    public static String DRY_ResultAction_MultipleNewWarnings(Object arg1) {
        return holder.format("DRY.ResultAction.MultipleNewWarnings", arg1);
    }

    /**
     * {0} new warnings
     * 
     */
    public static Localizable _DRY_ResultAction_MultipleNewWarnings(Object arg1) {
        return new Localizable(holder, "DRY.ResultAction.MultipleNewWarnings", arg1);
    }

    /**
     * Publish duplicate code analysis results
     * 
     */
    public static String DRY_Publisher_Name() {
        return holder.format("DRY.Publisher.Name");
    }

    /**
     * Publish duplicate code analysis results
     * 
     */
    public static Localizable _DRY_Publisher_Name() {
        return new Localizable(holder, "DRY.Publisher.Name");
    }

    /**
     * from {0} analysis files.
     * 
     */
    public static String DRY_ResultAction_MultipleFiles(Object arg1) {
        return holder.format("DRY.ResultAction.MultipleFiles", arg1);
    }

    /**
     * from {0} analysis files.
     * 
     */
    public static Localizable _DRY_ResultAction_MultipleFiles(Object arg1) {
        return new Localizable(holder, "DRY.ResultAction.MultipleFiles", arg1);
    }

    /**
     * Duplicate code: {0} warnings found.
     * 
     */
    public static String DRY_ResultAction_HealthReportMultipleItem(Object arg1) {
        return holder.format("DRY.ResultAction.HealthReportMultipleItem", arg1);
    }

    /**
     * Duplicate code: {0} warnings found.
     * 
     */
    public static Localizable _DRY_ResultAction_HealthReportMultipleItem(Object arg1) {
        return new Localizable(holder, "DRY.ResultAction.HealthReportMultipleItem", arg1);
    }

    /**
     * {0} fixed warnings
     * 
     */
    public static String DRY_ResultAction_MultipleFixedWarnings(Object arg1) {
        return holder.format("DRY.ResultAction.MultipleFixedWarnings", arg1);
    }

    /**
     * {0} fixed warnings
     * 
     */
    public static Localizable _DRY_ResultAction_MultipleFixedWarnings(Object arg1) {
        return new Localizable(holder, "DRY.ResultAction.MultipleFixedWarnings", arg1);
    }

    /**
     * from one analysis file.
     * 
     */
    public static String DRY_ResultAction_OneFile() {
        return holder.format("DRY.ResultAction.OneFile");
    }

    /**
     * from one analysis file.
     * 
     */
    public static Localizable _DRY_ResultAction_OneFile() {
        return new Localizable(holder, "DRY.ResultAction.OneFile");
    }

    /**
     * Duplicate code: one warning found.
     * 
     */
    public static String DRY_ResultAction_HealthReportSingleItem() {
        return holder.format("DRY.ResultAction.HealthReportSingleItem");
    }

    /**
     * Duplicate code: one warning found.
     * 
     */
    public static Localizable _DRY_ResultAction_HealthReportSingleItem() {
        return new Localizable(holder, "DRY.ResultAction.HealthReportSingleItem");
    }

    /**
     * Duplicate Code Trend
     * 
     */
    public static String DRY_Trend_Name() {
        return holder.format("DRY.Trend.Name");
    }

    /**
     * Duplicate Code Trend
     * 
     */
    public static Localizable _DRY_Trend_Name() {
        return new Localizable(holder, "DRY.Trend.Name");
    }

    /**
     * New Duplicate Code Warnings
     * 
     */
    public static String DRY_NewWarnings_Detail_header() {
        return holder.format("DRY.NewWarnings.Detail.header");
    }

    /**
     * New Duplicate Code Warnings
     * 
     */
    public static Localizable _DRY_NewWarnings_Detail_header() {
        return new Localizable(holder, "DRY.NewWarnings.Detail.header");
    }

    /**
     * Duplicate Code
     * 
     */
    public static String DRY_Detail_header() {
        return holder.format("DRY.Detail.header");
    }

    /**
     * Duplicate Code
     * 
     */
    public static Localizable _DRY_Detail_header() {
        return new Localizable(holder, "DRY.Detail.header");
    }

    /**
     *  1 warning
     * 
     */
    public static String DRY_ResultAction_OneWarning() {
        return holder.format("DRY.ResultAction.OneWarning");
    }

    /**
     *  1 warning
     * 
     */
    public static Localizable _DRY_ResultAction_OneWarning() {
        return new Localizable(holder, "DRY.ResultAction.OneWarning");
    }

    /**
     * {0} lines of duplicate code.
     * 
     */
    public static String DRY_Warning_Message(Object arg1) {
        return holder.format("DRY.Warning.Message", arg1);
    }

    /**
     * {0} lines of duplicate code.
     * 
     */
    public static Localizable _DRY_Warning_Message(Object arg1) {
        return new Localizable(holder, "DRY.Warning.Message", arg1);
    }

    /**
     *  1 fixed warning
     * 
     */
    public static String DRY_ResultAction_OneFixedWarning() {
        return holder.format("DRY.ResultAction.OneFixedWarning");
    }

    /**
     *  1 fixed warning
     * 
     */
    public static Localizable _DRY_ResultAction_OneFixedWarning() {
        return new Localizable(holder, "DRY.ResultAction.OneFixedWarning");
    }

    /**
     * Fixed Duplicate Code Warnings
     * 
     */
    public static String DRY_FixedWarnings_Detail_header() {
        return holder.format("DRY.FixedWarnings.Detail.header");
    }

    /**
     * Fixed Duplicate Code Warnings
     * 
     */
    public static Localizable _DRY_FixedWarnings_Detail_header() {
        return new Localizable(holder, "DRY.FixedWarnings.Detail.header");
    }

    /**
     * Duplicate code: no warnings found.
     * 
     */
    public static String DRY_ResultAction_HealthReportNoItem() {
        return holder.format("DRY.ResultAction.HealthReportNoItem");
    }

    /**
     * Duplicate code: no warnings found.
     * 
     */
    public static Localizable _DRY_ResultAction_HealthReportNoItem() {
        return new Localizable(holder, "DRY.ResultAction.HealthReportNoItem");
    }

    /**
     * {0} warnings
     * 
     */
    public static String DRY_ResultAction_MultipleWarnings(Object arg1) {
        return holder.format("DRY.ResultAction.MultipleWarnings", arg1);
    }

    /**
     * {0} warnings
     * 
     */
    public static Localizable _DRY_ResultAction_MultipleWarnings(Object arg1) {
        return new Localizable(holder, "DRY.ResultAction.MultipleWarnings", arg1);
    }

}

==> dry-2.4-sources.jar: hudson/plugins/dry/Messages.java <==
// CHECKSTYLE:OFF

package hudson.plugins.dry;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;

@SuppressWarnings({
    "",
    "PMD"
})
public class Messages {

    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     *  1 new warning
     * 
     */
    public static String DRY_ResultAction_OneNewWarning() {
        return holder.format("DRY.ResultAction.OneNewWarning");
    }

    /**
     *  1 new warning
     * 
     */
    public static Localizable _DRY_ResultAction_OneNewWarning() {
        return new Localizable(holder, "DRY.ResultAction.OneNewWarning");
    }

    /**
     * Duplicate Code
     * 
     */
    public static String DRY_ProjectAction_Name() {
        return holder.format("DRY.ProjectAction.Name");
    }

    /**
     * Duplicate Code
     * 
     */
    public static Localizable _DRY_ProjectAction_Name() {
        return new Localizable(holder, "DRY.ProjectAction.Name");
    }

    /**
     * Duplicate code per project
     * 
     */
    public static String Portlet_WarningsTable() {
        return holder.format("Portlet.WarningsTable");
    }

    /**
     * Duplicate code per project
     * 
     */
    public static Localizable _Portlet_WarningsTable() {
        return new Localizable(holder, "Portlet.WarningsTable");
    }

    /**
     * {0} new warnings
     * 
     */
    public static String DRY_ResultAction_MultipleNewWarnings(Object arg1) {
        return holder.format("DRY.ResultAction.MultipleNewWarnings", arg1);
    }

    /**
     * {0} new warnings
     * 
     */
    public static Localizable _DRY_ResultAction_MultipleNewWarnings(Object arg1) {
        return new Localizable(holder, "DRY.ResultAction.MultipleNewWarnings", arg1);
    }

    /**
     * Publish duplicate code analysis results
     * 
     */
    public static String DRY_Publisher_Name() {
        return holder.format("DRY.Publisher.Name");
    }

    /**
     * Publish duplicate code analysis results
     * 
     */
    public static Localizable _DRY_Publisher_Name() {
        return new Localizable(holder, "DRY.Publisher.Name");
    }

    /**
     * from {0} analysis files.
     * 
     */
    public static String DRY_ResultAction_MultipleFiles(Object arg1) {
        return holder.format("DRY.ResultAction.MultipleFiles", arg1);
    }

    /**
     * from {0} analysis files.
     * 
     */
    public static Localizable _DRY_ResultAction_MultipleFiles(Object arg1) {
        return new Localizable(holder, "DRY.ResultAction.MultipleFiles", arg1);
    }

    /**
     * Duplicate code: {0} warnings found.
     * 
     */
    public static String DRY_ResultAction_HealthReportMultipleItem(Object arg1) {
        return holder.format("DRY.ResultAction.HealthReportMultipleItem", arg1);
    }

    /**
     * Duplicate code: {0} warnings found.
     * 
     */
    public static Localizable _DRY_ResultAction_HealthReportMultipleItem(Object arg1) {
        return new Localizable(holder, "DRY.ResultAction.HealthReportMultipleItem", arg1);
    }

    /**
     * {0} fixed warnings
     * 
     */
    public static String DRY_ResultAction_MultipleFixedWarnings(Object arg1) {
        return holder.format("DRY.ResultAction.MultipleFixedWarnings", arg1);
    }

    /**
     * {0} fixed warnings
     * 
     */
    public static Localizable _DRY_ResultAction_MultipleFixedWarnings(Object arg1) {
        return new Localizable(holder, "DRY.ResultAction.MultipleFixedWarnings", arg1);
    }

    /**
     * from one analysis file.
     * 
     */
    public static String DRY_ResultAction_OneFile() {
        return holder.format("DRY.ResultAction.OneFile");
    }

    /**
     * from one analysis file.
     * 
     */
    public static Localizable _DRY_ResultAction_OneFile() {
        return new Localizable(holder, "DRY.ResultAction.OneFile");
    }

    /**
     * Duplicate code: one warning found.
     * 
     */
    public static String DRY_ResultAction_HealthReportSingleItem() {
        return holder.format("DRY.ResultAction.HealthReportSingleItem");
    }

    /**
     * Duplicate code: one warning found.
     * 
     */
    public static Localizable _DRY_ResultAction_HealthReportSingleItem() {
        return new Localizable(holder, "DRY.ResultAction.HealthReportSingleItem");
    }

    /**
     * Duplicate Code Trend
     * 
     */
    public static String DRY_Trend_Name() {
        return holder.format("DRY.Trend.Name");
    }

    /**
     * Duplicate Code Trend
     * 
     */
    public static Localizable _DRY_Trend_Name() {
        return new Localizable(holder, "DRY.Trend.Name");
    }

    /**
     * New Duplicate Code Warnings
     * 
     */
    public static String DRY_NewWarnings_Detail_header() {
        return holder.format("DRY.NewWarnings.Detail.header");
    }

    /**
     * New Duplicate Code Warnings
     * 
     */
    public static Localizable _DRY_NewWarnings_Detail_header() {
        return new Localizable(holder, "DRY.NewWarnings.Detail.header");
    }

    /**
     * Duplicate Code
     * 
     */
    public static String DRY_Detail_header() {
        return holder.format("DRY.Detail.header");
    }

    /**
     * Duplicate Code
     * 
     */
    public static Localizable _DRY_Detail_header() {
        return new Localizable(holder, "DRY.Detail.header");
    }

    /**
     *  1 warning
     * 
     */
    public static String DRY_ResultAction_OneWarning() {
        return holder.format("DRY.ResultAction.OneWarning");
    }

    /**
     *  1 warning
     * 
     */
    public static Localizable _DRY_ResultAction_OneWarning() {
        return new Localizable(holder, "DRY.ResultAction.OneWarning");
    }

    /**
     * {0} lines of duplicate code.
     * 
     */
    public static String DRY_Warning_Message(Object arg1) {
        return holder.format("DRY.Warning.Message", arg1);
    }

    /**
     * {0} lines of duplicate code.
     * 
     */
    public static Localizable _DRY_Warning_Message(Object arg1) {
        return new Localizable(holder, "DRY.Warning.Message", arg1);
    }

    /**
     *  1 fixed warning
     * 
     */
    public static String DRY_ResultAction_OneFixedWarning() {
        return holder.format("DRY.ResultAction.OneFixedWarning");
    }

    /**
     *  1 fixed warning
     * 
     */
    public static Localizable _DRY_ResultAction_OneFixedWarning() {
        return new Localizable(holder, "DRY.ResultAction.OneFixedWarning");
    }

    /**
     * Fixed Duplicate Code Warnings
     * 
     */
    public static String DRY_FixedWarnings_Detail_header() {
        return holder.format("DRY.FixedWarnings.Detail.header");
    }

    /**
     * Fixed Duplicate Code Warnings
     * 
     */
    public static Localizable _DRY_FixedWarnings_Detail_header() {
        return new Localizable(holder, "DRY.FixedWarnings.Detail.header");
    }

    /**
     * Duplicate code: no warnings found.
     * 
     */
    public static String DRY_ResultAction_HealthReportNoItem() {
        return holder.format("DRY.ResultAction.HealthReportNoItem");
    }

    /**
     * Duplicate code: no warnings found.
     * 
     */
    public static Localizable _DRY_ResultAction_HealthReportNoItem() {
        return new Localizable(holder, "DRY.ResultAction.HealthReportNoItem");
    }

    /**
     * {0} warnings
     * 
     */
    public static String DRY_ResultAction_MultipleWarnings(Object arg1) {
        return holder.format("DRY.ResultAction.MultipleWarnings", arg1);
    }

    /**
     * {0} warnings
     * 
     */
    public static Localizable _DRY_ResultAction_MultipleWarnings(Object arg1) {
        return new Localizable(holder, "DRY.ResultAction.MultipleWarnings", arg1);
    }

}
